@@ -290,30 +290,66 @@ which case convert the entirety of it.  Also see `denote-sequence-scheme'."
         (error "String `%s' did not pass `denote-sequence-p'" string)
       (error "The `%s' must not contain both numbers and letters" string)))))
 
-(defun denote-sequence-increment (string)
+(define-obsolete-function-alias
+  'denote-sequence-increment
+  'denote-sequence-increment-partial
+  "0.2.0")
+
+(defun denote-sequence-increment-partial (string)
   "Increment number represented by STRING and return it as a string.
-STRING is part of a sequence, not the entirety of it."
+STRING is part of a sequence, not the entirety of it.
+
+Also see `denote-sequence-decrement-partial'."
   (cond
    ((denote-sequence--numeric-partial-p string)
     (number-to-string (+ (string-to-number string) 1)))
    ((denote-sequence--alphanumeric-partial-p string)
     (let* ((letters (split-string string "" :omit-nulls))
-           (length-1 (= (length letters) 1))
+           (length-1-p (= (length letters) 1))
            (first (car letters))
            (reverse (nreverse (copy-sequence letters)))
            (last (car reverse)))
       (cond
-       ((and length-1 (string= "z" first))
+       ((and length-1-p (string= "z" first))
         "za")
-       (length-1
+       (length-1-p
         (char-to-string (+ (string-to-char first) 1)))
        ((string= "z" last)
         (apply #'concat (append letters (list "a"))))
        (t
-        (let ((last last))
-          (apply #'concat
-                 (append (butlast letters)
-                         (list (char-to-string (+ (string-to-char last) 1))))))))))
+        (apply #'concat
+               (append (butlast letters)
+                       (list (char-to-string (+ (string-to-char last) 1)))))))))
+   (t
+    (error "The string `%s' must contain only numbers or letters" string))))
+
+(defun denote-sequence-decrement-partial (string)
+  "Decrement number represented by STRING and return it as a string.
+STRING is part of a sequence, not the entirety of it.
+
+Also see `denote-sequence-increment-partial'."
+  (cond
+   ((denote-sequence--numeric-partial-p string)
+    (let ((number (string-to-number string)))
+      (unless (= number 1)
+        (number-to-string (- number 1)))))
+   ((denote-sequence--alphanumeric-partial-p string)
+    (let* ((letters (split-string string "" :omit-nulls))
+           (length-1-p (= (length letters) 1))
+           (first (car letters))
+           (reverse (nreverse (copy-sequence letters)))
+           (last (car reverse)))
+      (cond
+       ((and length-1-p (string= "a" first))
+        nil)
+       (length-1-p
+        (char-to-string (- (string-to-char first) 1)))
+       ((string= "a" last)
+        (apply #'concat (butlast letters)))
+       (t
+        (apply #'concat
+               (append (butlast letters)
+                       (list (char-to-string (- (string-to-char last) 1)))))))))
    (t
     (error "The string `%s' must contain only numbers or letters" string))))
 
@@ -357,21 +393,57 @@ depth given SEQUENCE."
                            (t (error "Unknown type of sequence for `%s'" last-component)))))
     (denote-sequence-join (list sequence new-depth) scheme)))
 
-(defun denote-sequence--get-files (&optional files)
-  "Return list of files or buffers in the variable `denote-directory'.
-With optional FILES only consider those, otherwise use `denote-directory-files'."
-  (let* ((denote-directory (or denote-use-directory (denote-directory)))
-         (files (denote-directory-files))
-         (buffers (denote--buffer-file-names)))
-    (delete-dups (append buffers files))))
+(defun denote-sequence--infer-sibling (sequence direction)
+  "Get sibling of SEQUENCE in DIRECTION `next' or `previous'.
+Do not actually try to create a new sibling nor to test for the
+existence of one.  Simply do the work of finding the next or previous
+sibling in the sequence."
+  (pcase-let* ((`(,sequence . ,scheme) (denote-sequence-and-scheme-p sequence))
+               (components (denote-sequence-split sequence))
+               (butlast (butlast components))
+               (last-component (car (nreverse components)))
+               (direction-fn (pcase direction
+                               ('next #'denote-sequence-increment-partial)
+                               ('previous #'denote-sequence-decrement-partial)
+                               (_ (error "Unknown DIRECTION `%s'" direction))))
+               (new-number (funcall direction-fn last-component)))
+    (when new-number
+      (denote-sequence-join (append butlast (list new-number)) scheme))))
 
+(defun denote-sequence--get-files (files)
+  "Return list of FILES plus any buffers in the variable `denote-directory'."
+  (delete-dups (append (denote--buffer-file-names) files)))
+
+;; TODO 2025-06-23: Return cons cells with sequences and files.  This
+;; is to be able to do an `alist-get' to get a path given a sequence.
 (defun denote-sequence-get-all-files (&optional files)
   "Return all files in variable `denote-directory' with a sequence.
 A sequence is a Denote signature that conforms with `denote-sequence-p'.
 
 With optional FILES consider only those, otherwise use the return value
 of `denote-directory-files'."
-  (seq-filter #'denote-sequence-file-p (denote-sequence--get-files files)))
+  (when-let* ((files (denote-sequence--get-files (or files (denote-directory-files)))))
+    (seq-filter #'denote-sequence-file-p files)))
+
+(defun denote-sequence-get-path (sequence &optional files)
+  "Return absolute path of file with SEQUENCE.
+Search in the return value of `denote-sequence-get-all-files' or in FILES."
+  (let ((files
+         (seq-filter
+          (lambda (file)
+            (string= sequence (denote-retrieve-filename-signature file)))
+          (denote-sequence-get-all-files files))))
+    (if (length< files 2)
+        (car files)
+      (seq-find
+       (lambda (file)
+         (let ((file-extension (denote-get-file-extension-sans-encryption file)))
+           (and (denote-file-has-supported-extension-p file)
+                (or (string= (denote--file-extension denote-file-type)
+                             file-extension)
+                    (string= ".org" file-extension)
+                    (member file-extension (denote-file-type-extensions))))))
+       files))))
 
 (defun denote-sequence--sequence-prefix-p (prefix sequence)
   "Return non-nil if SEQUENCE has prefix sequence PREFIX.
@@ -568,7 +640,7 @@ function `denote-sequence-get-all-sequences-with-prefix'."
                              (components (denote-sequence-split largest))
                              (butlast (butlast components))
                              (last-component (car (nreverse components)))
-                             (new-number (denote-sequence-increment last-component)))
+                             (new-number (denote-sequence-increment-partial last-component)))
                   (denote-sequence-join
                    (if butlast
                        (append butlast (list new-number))
@@ -606,7 +678,7 @@ function `denote-sequence-get-all-sequences-with-prefix'."
                          (components (denote-sequence-split largest))
                          (butlast (butlast components))
                          (last-component (car (nreverse components)))
-                         (new-number (denote-sequence-increment last-component)))
+                         (new-number (denote-sequence-increment-partial last-component)))
               (denote-sequence-join (append butlast (list new-number)) scheme))
           (number-to-string (+ (string-to-number largest) 1)))
       (error "Cannot find sequences given sequence `%s' using scheme `%s'" sequence denote-sequence-scheme))))
@@ -639,7 +711,7 @@ returned by `denote-sequence-get-all-files'."
     (pcase type
       ('all-parents (let ((parents nil)
                           (butlast (butlast components)))
-                      (while (>= (length butlast) 1)
+                      (while (> (length butlast) 1)
                         (when-let* ((prefix (denote-sequence-join butlast scheme))
                                     (parent (seq-find
                                              (lambda (file)
@@ -713,7 +785,7 @@ completion candidates.  Else use `denote-sequence-get-all-files'."
                     (denote--completion-table 'file relative-files)
                     nil :require-match
                     nil 'denote-sequence-file-history)))
-      (concat (denote-directory) input)
+      (expand-file-name input (denote-directory))
     (error "There are no sequence notes in the `denote-directory'")))
 
 ;;;###autoload
@@ -807,6 +879,26 @@ If the current file does not have a sequence, then behave exactly like
          (denote-use-signature new-sequence))
     (call-interactively 'denote)))
 
+;;;###autoload
+(defun denote-sequence-find-next-sibling (sequence)
+  "Visit the next sibling of file with SEQUENCE."
+  (interactive (list (denote-sequence--get-file-in-dired-or-prompt "Make a new sibling of SEQUENCE")))
+  (if-let* ((relatives (denote-sequence-get-relative sequence 'siblings))
+            (next-sequence (denote-sequence--infer-sibling sequence 'next))
+            (path (denote-sequence-get-path next-sequence relatives)))
+      (find-file path)
+    (user-error "No next sibling for sequence `%s'" sequence)))
+
+;;;###autoload
+(defun denote-sequence-find-previous-sibling (sequence)
+  "Visit the previous sibling of file with SEQUENCE."
+  (interactive (list (denote-sequence--get-file-in-dired-or-prompt "Make a new sibling of SEQUENCE")))
+  (if-let* ((relatives (denote-sequence-get-relative sequence 'siblings))
+            (previous-sequence (denote-sequence--infer-sibling sequence 'previous))
+            (path (denote-sequence-get-path previous-sequence relatives)))
+      (find-file path)
+    (user-error "No previous sibling for sequence `%s'" sequence)))
+
 (defvar denote-sequence-relative-types
   '(all-parents parent siblings children all-children)
   "Types of sequence relatives.")
@@ -930,26 +1022,26 @@ For a more specialised case, see `denote-sequence-find-relatives-dired'."
         (denote-sequence-prompt "Limit to files that extend SEQUENCE (empty for all)")))
       (t
        nil))))
-  (if-let* ((default-directory (denote-directory))
-            (all (if prefix
-                     (denote-sequence-get-all-files-with-prefix prefix)
-                   (denote-sequence-get-all-files)))
-            (files-with-depth (if depth
-                                  (denote-sequence-get-all-files-with-max-depth depth all)
-                                all))
-            (files-sorted (denote-sequence-sort-files files-with-depth))
-            (buffer-name (denote-sequence--get-dired-buffer-name prefix depth)))
-      (let ((dired-buffer (dired (cons buffer-name (mapcar #'file-relative-name files-sorted)))))
-        (with-current-buffer dired-buffer
-          (setq-local revert-buffer-function
-                      (lambda (&rest _)
-                        ;; FIXME 2025-01-04: Killing the buffer has
-                        ;; the unintended side effect of affecting the
-                        ;; window configuration when we call
-                        ;; `denote-update-dired-buffers'.
-                        (kill-buffer dired-buffer)
-                        (denote-sequence-dired prefix depth)))))
-    (user-error "No Denote sequences matching those terms")))
+  (pcase-let* ((relative-p (denote-has-single-denote-directory-p))
+               (files-fn `(lambda ()
+                            (let* ((files (if ,prefix
+                                              (denote-sequence-get-all-files-with-prefix ,prefix)
+                                            (denote-sequence-get-all-files)))
+                                   (files-with-depth (if ,depth
+                                                         (denote-sequence-get-all-files-with-max-depth ,depth files)
+                                                       files))
+                                   (files-sorted (denote-sequence-sort-files files-with-depth)))
+                              (if ,relative-p
+                                  (mapcar #'file-relative-name files-sorted)
+                                files-sorted)))))
+    (if-let* ((directory (if relative-p ; see comment in `denote-file-prompt'
+                             (car (denote-directories))
+                           (denote-sort-dired--find-common-directory (denote-directories))))
+              (files (funcall files-fn))
+              (dired-name (format-message "prefix `%s'; depth `%s'" (or prefix "ALL") (or depth "ALL")))
+              (buffer-name dired-name))
+        (denote-sort-dired--prepare-buffer directory files-fn dired-name buffer-name)
+      (message "No matching files for: %s" files-matching-regexp))))
 
 ;;;###autoload
 (defun denote-sequence-find-dired (type)
@@ -973,6 +1065,14 @@ Also see `denote-sequence-dired'."
         (user-error "The sequence `%s' has no relatives of type `%s'" sequence type))
     (user-error "The current file has no sequence")))
 
+(defun denote-sequence--get-current-file-for-renaming ()
+  "Return path to file for a rename operation.
+The path is that of the special Org buffer (like `org-capture'), the
+file at point in a Dired buffer, or the variable `buffer-file-name'."
+  (if (denote--file-type-org-extra-p)
+      denote-last-path-after-rename
+    (denote--rename-dired-file-or-current-file-or-prompt)))
+
 ;; TODO 2025-01-14: We need to have an operation that reparents
 ;; recursively.  This can be done inside of the `denote-sequence-reparent',
 ;; where if it finds that the current file has children, it prompts
@@ -999,9 +1099,7 @@ such (per `denote-sequence-p').  In both cases, what matters is to know
 the target sequence."
   (interactive
    (list
-    (if (denote--file-type-org-extra-p)
-        denote-last-path-after-rename
-      (denote--rename-dired-file-or-current-file-or-prompt))
+    (denote-sequence--get-current-file-for-renaming)
     (denote-sequence-file-prompt
      (format "Reparent `%s' to be a child of"
              (propertize
@@ -1011,7 +1109,22 @@ the target sequence."
                               (denote-sequence-p file-with-sequence)
                               (user-error "No sequence of `denote-sequence-p' found in `%s'" file-with-sequence)))
          (new-sequence (denote-sequence--get-new-child target-sequence)))
-    (denote-rename-file current-file 'keep-current 'keep-current new-sequence 'keep-current)))
+    (denote-rename-file current-file 'keep-current 'keep-current new-sequence 'keep-current 'keep-current)))
+
+;;;###autoload
+(defun denote-sequence-rename-as-parent (current-file)
+  "Make CURRENT-FILE a new parent sequence.
+If CURRENT-FILE has a sequence abort the operation.
+
+When called interactively, CURRENT-FILE is either the current file, or a
+special Org buffer (like those of `org-capture'), or the file at point
+in Dired.  When called from Lisp, CURRENT-FILE is a string pointing to a
+file."
+  (interactive (list (denote-sequence--get-current-file-for-renaming)))
+  (when (denote-sequence-file-p current-file)
+    (user-error "The `%s' already has a sequence; aborting" current-file))
+  (let ((new-sequence (denote-sequence--get-new-parent)))
+    (denote-rename-file current-file 'keep-current 'keep-current new-sequence 'keep-current 'keep-current)))
 
 ;;;###autoload
 (defun denote-sequence-convert (files)
@@ -1038,7 +1151,7 @@ CHECK THE RESULTING SEQUENCES FOR DUPLICATES."
   (dolist (file files)
     (when-let* ((old-sequence (denote-sequence-file-p file))
                 (new-sequence (denote-sequence-make-conversion old-sequence :is-complete-sequence)))
-      (denote-rename-file file 'keep-current 'keep-current new-sequence 'keep-current)))
+      (denote-rename-file file 'keep-current 'keep-current new-sequence 'keep-current 'keep-current)))
   (denote-update-dired-buffers))
 
 (provide 'denote-sequence)
